@@ -1,5 +1,5 @@
 /*
- *  $Id: dialog.h,v 1.287 2019/08/05 21:30:42 tom Exp $
+ *  $Id: dialog.h,v 1.290 2019/11/10 23:17:37 tom Exp $
  *
  *  dialog.h -- common declarations for all dialog modules
  *
@@ -615,12 +615,16 @@ extern DIALOG_VARS dialog_vars;
  * Table for attribute- and color-values.
  */
 typedef struct {
-    chtype atr;
+    chtype atr;			/* attribute corresponding to fg, bg, etc */
 #ifdef DLG_HAVE_COLOR
-    int fg;
-    int bg;
-    int hilite;
-#endif
+    int fg;			/* foreground color-number */
+    int bg;			/* background color-number */
+    int hilite;			/* true if bold */
+#ifdef DLG_HAVE_RC_FILE2
+    int ul;			/* true if underline */
+    int rv;			/* true if reverse */
+#endif /* DLG_HAVE_RC_FILE2 */
+#endif /* DLG_HAVE_COLOR */
 #ifdef DLG_HAVE_RC_FILE
     const char *name;
     const char *comment;
@@ -867,6 +871,7 @@ extern int dlg_strcmp(const char * /*a*/, const char * /*b*/);
 #ifdef DLG_HAVE_DLG_TRACE
 #define DLG_TRACE(params) dlg_trace_msg params
 extern void dlg_trace_msg(const char *fmt, ...) GCC_PRINTFLIKE(1,2);
+extern void dlg_trace_va_msg(const char *fmt, va_list ap);
 #define DLG_TRACE2S(name,value) dlg_trace_2s (name,value)
 #define DLG_TRACE2N(name,value) dlg_trace_2n (name,value)
 extern void dlg_trace_2s(const char * /*name*/, const char * /*value*/);
@@ -878,6 +883,7 @@ extern void dlg_trace(const char * /*fname*/);
 #define DLG_TRACE(params) /* nothing */
 #define DLG_TRACE2S(name,value) /* nothing */
 #define DLG_TRACE2N(name,value) /* nothing */
+#define dlg_trace_va_msg(fmt, ap) /* nothing */
 #define dlg_trace_win(win) /* nothing */
 #define dlg_trace_chr(ch,fkey) /* nothing */
 #define dlg_trace(fname) /* nothing */
